% This code performs a multiple curves fitting of the Capillary model 
% to the inversely determined experimental data.
% The model describes the inter-yarn angle and normal force dependence
% of the capillary forces using 3 parameters.
% The inversely determined experimental data were available for:
% T300J-T300J (capilary_t300j.txt)
% IM7-T300J (capilary_t300j_im7.txt)
% Eglass-T300J (capilary_t300j_eglass.txt)

% Programmer: Anh Ngoc Vu, University of Twente
% Email: a.n.vu@utwente.nl

close all
clc
clear all

% read inversely determined experimental data.
data_exp = dlmread('capilary_t300j.txt'); % change the .txt file name to read different data.
input_BC = data_exp(:,2:2:end);
ub = [inf,inf,inf]; % set fitting upper boundary
lb = [-inf,-inf,-inf]; % set fitting lower boundary
para_initial = [0.1, 1, 1]; % set initial guesses for the 3 parameters r_c, n_f, k_a
options = optimoptions('lsqcurvefit','MaxFunctionEvaluations', 500,...
                       'Algorithm','trust-region-reflective',...
                       'MaxIterations',500,...
                       'OptimalityTolerance', 1e-8,...
                       'FunctionTolerance', 1e-8,...
                       'StepTolerance', 1e-8,...
                       'Display','iter'); % set fitting options
% multiple curve fit using lsqcurvefit function
[para_cur,resnorm_cur] = lsqcurvefit(@func_capilary,para_initial,input_BC,input_BC, lb, ub, options);
% presenting resultal parameters
r_c = para_cur(1)
n_f = para_cur(2)
k_a = para_cur(3)
% represent fitted curves
[Fcap] = func_capilary(para_cur,input_BC); 

